require 'spec_helper'

describe Url2Event::Eventbrite do
  let(:url) { URI.parse("http://www.eventbrite.com/e/startup-weekend-seattle-0822-tickets-12095703575?aff=eac2") }
  let(:uk_url) { URI.parse("http://www.eventbrite.co.uk/e/london-fintech-startups-tmufintech-tickets-10220306211?aff=es2&rank=11") }

  describe ".is_parser_for?" do
    it { expect(described_class.is_parser_for?(url)).to eql(true) }
    it { expect(described_class.is_parser_for?(uk_url)).to eql(true) }
  end

  describe "get_event", :vcr do
    let(:begin_at) { Time.parse("2014-10-03 18:00:00 +0000") }
    let(:end_at) { Time.parse("2014-10-05 21:00:00 +0000") }
    let(:parser) { described_class.new(url) }
    subject { parser.get_event }

    it { should be_instance_of(Event) }
    its(:title) { should eql("Startup Weekend Seattle 10/3") }
    its(:location) { should eql("Zillow Seattle Headquarters") }
    its(:description) { should_not include("<") }
    its(:begin_at) { should eql(begin_at) }
    its(:end_at) { should eql(end_at) }
    its(:link) { should eql("http://swseattle0814.eventbrite.com") }

    context "when the url is unparsable" do
      let(:unparsable) { URI.parse("http://www.eventbrite.com/home") }
      let(:parser) { described_class.new(unparsable) }
      subject { -> {parser.get_event } }
      it { should raise_error(Url2Event::UnparsableSourceError) }
    end
  end
end
