require 'spec_helper'

describe Url2Event::Meetup do
  let(:url) { URI.parse("http://www.meetup.com/Startup-Grind-Seattle/events/187282242/") }
  describe ".is_parser_for?" do
    it { expect(described_class.is_parser_for?(url)).to eql(true) }
  end

  describe "get_event", :vcr do
    let(:begin_at) { Time.parse("2014-07-29 18:00:00 +0000") }
    let(:end_at) { Time.parse("2014-07-29 21:00:00 +0000") }
    let(:parser) { described_class.new(url) }

    subject { parser.get_event }

    it { should be_instance_of(Event) }
    its(:title) { should eql("Startup Grind Seattle Hosts Robert Scoble, Tech Geek (Rackspace)") }
    its(:begin_at) { should eql(begin_at) }
    its(:end_at) { should eql(end_at) }
    its(:location) { should eql("Dice Cabana at SURF, 821 2nd Avenue #410, Seattle") }
    its(:description) { should_not include("<") }
    its(:price) { should be_nil }

    context "when the url is unparsable" do
      let(:unparsable) { URI.parse("http://www.meetup.com/Startup-Grind-Seattle") }
      let(:parser) { described_class.new(unparsable) }
      subject { -> { parser.get_event } }
      it { should raise_error(Url2Event::UnparsableSourceError) }
    end
  end
end
