describe Url2Event, :vcr do
  describe ".parse_event_from_uri" do
    let(:url) { "http://www.meetup.com/BKtechmeetup/events/191161262/" }
    subject { Url2Event.parse_event_from_uri(url) }
    it { should be_instance_of(Event) }

    context "when given an invalid url." do
      let(:bad_url) { "catscats::///////www//w////ww/coom" }
      subject(:parser) {-> { Url2Event.parse_event_from_uri(bad_url) } }
      it { expect(parser).to raise_error(Url2Event::InvalidURLError) }
    end
  end

  describe ".get_parser_class" do
    context "when given a meetup event" do
      let(:url) { URI.parse("http://www.meetup.com/BKtechmeetup/events/191161262/") }
      subject(:parser) { Url2Event.get_parser_class(url) }
      it { expect(parser).to be(Url2Event::Meetup) }
    end

    context "when given an eventbrite event." do
      let(:url) { URI.parse("http://www.eventbrite.com/e/startup-weekend-seattle-0822-tickets-12095703575?aff=eac2") }
      subject(:parser) { Url2Event.get_parser_class(url) }
      it { expect(parser).to be(Url2Event::Eventbrite) }
    end

    context "when given an unsupported url." do
      let(:url) { URI.parse("http://www.geekwire.com/events/sounders-day-2014/") }
      subject(:parser) { -> { Url2Event.get_parser_class(url)} }
      it { expect(parser).to raise_error(Url2Event::UnsupportedSourceError) }
    end
  end
end
